==> abi-0.7.9.tar.gz: abi-0.7.9/src/wp/ap/xp/ap_Menu_LabelSet_hu-HU.h <==
/* AbiWord
 * Copyright (C) 2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Hungarian translations provided by Tamas Decsi <tamas@pressflex.com>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the second argument is UT_TRUE, then this is the fall-back for
// this language (named in the first two letters).

BeginSet(hu,HU,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Fjl",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&j", 			"j dokumentum ltrehozsa")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"Meg&nyits",			"Dokumentum megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Bezrs", 			"Dokumentum bezrsa")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Ments", 			"Dokumentum mentse")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Ments &msknt", 		"Dokumentum mentse ms nven")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"&Oldalbellts",		"Nyomtatsi belltsok")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Nyomtats",			"A teljes dokumentum, vagy egy rsznek nyomtatsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Kilps", 			"Az alkalmazs sszes ablaknak bezrsa s kilps")

	MenuLabel(AP_MENU_ID_EDIT,				"&Szerkeszts",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Visszavon",			"Szerkeszts visszavonsa")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"j&ra",			"Az elz visszavons jra")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Kivgs",				"A kijellt rszt kivgja, s a vglapra helyezi")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Msols",			"A kijellt rszt a vglapra msolja")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"&Beilleszts",			"A vglap tartalmt beszrja")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Trls",			"A kijells trlse")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"Mindent kijel&l",		"A teljes dokumentum kijellse")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"Kere&s",			"A megadott szveg keresse")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"Cs&erl",			"A megadott szveg cserje ms szvegre")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"U&grs",			"A kurzor thelyezse egy megadott helyre")
	MenuLabel(AP_MENU_ID_TOOLS,		"&Eszkzk",		NULL)
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Helyesrs",		"A dokumentum helyesrsnak ellenrzse")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,		"&Szavak szma",		"A dokumentum szavainak megszmllsa")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Belltsok",			"Belltsok szerkesztse")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Nzet",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Eszkztrak",		NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Szabvny",		"A szabvny eszkztr megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formzs",		"A formzs eszkztr megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Vonalz",			"A vonalzk megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"llapot&sor",		"Az llapotsor megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Bekezdsjelek",	"A nem nyomtatott karakterek megjelentse")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Fejlc s lblc",	"Az oldalak tetejn s aljn lv szveg szerkesztse")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Nagyts",			"A dokumentum nzet nagytsa vagy kicsinytse")

	MenuLabel(AP_MENU_ID_INSERT,			"&Beszrs",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"Trspont",			"Oldal-, Hasb-, vagy Szekcitrs beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"&Oldalszm",	"Automatikusan frisstett oldalszm beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"&Dtum s id",	"Dtum s/vagy id beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Mez",			"Szmtott mez beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Szimblum",			"Szimblum vagy specilis karakter beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"K&p",			"Meglv kp beszrsa fjlbl")

	MenuLabel(AP_MENU_ID_FORMAT,			"F&ormtum",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Bet",			"A kijellt szvegrsz bettpusnak megvltoztatsa")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"Be&kezds",		"A kijellt bekezds formzsa")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Fel&sorols",	"Felsorols hozzrendelse vagy mdostsa kijellt bekezdsekhez")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Sze&gly s rnyk",		"Szegly s rnyk hozzrendelse a kijellt rszhez")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Hasbok",			"A hasbok szmnak megvltoztatsa")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"S&tlus",			"Stlus megadsa vagy alkalmazsa a kijellt rszhez")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabultorok",			"Tabultorok belltsa")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Flkvr",			"A kijellt rsz flkvrr ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Dlt",			"A kijellt rsz dltt ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Alhzs",		"A kijellt rsz alhzsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"Fellvons",		"A kijellt rsz fellvonsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"Kihzs",			"A kijellt rsz kihzsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,	"Fels index",		"A kijellt rsz fels indexsz ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"Als index",		"A kijellt rsz als indexsz ttele (megfordts)")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Igazts",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Balra",			"A bekezds igaztsa balra")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Kzpre",			"A bekezds igaztsa kzpre")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Jobbra",			"A bekezds igaztsa jobbra")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Sorkiegyenlts",			"A bekezds sorkiegyenltse")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Ablak",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&j ablak",		"j ablak nyitsa a dokumentumnak")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Tovbbi ablakok",	"Az ablakok teljes listja")

	MenuLabel(AP_MENU_ID_HELP,				"S&g",			NULL)
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"%s &Nvjegy",		"Program informcik, verziszm s copyright megjelentse")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"M&indet Kihagy", 		"Hagyja figyelmen kvl a sz dokumentumbeli sszes elfordulst")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Felvesz", 			"Vegye fel ezt a szt az egyedi sztrba")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_Menu_LabelSet_hu-HU.h <==
/* AbiWord
 * Copyright (C) 2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

// Hungarian translations provided by Tamas Decsi <tamas.decsi@techie.com>

/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// We use the Win32 '&' character to denote a keyboard accelerator on a menu item.
// If your platform doesn't have a way to do accelerators or uses a different
// character, remove or change the '&' in your menu constructor code.

// If the second argument is UT_TRUE, then this is the fall-back for
// this language (named in the first two letters).

BeginSet(hu,HU,UT_TRUE)

	MenuLabel(AP_MENU_ID__BOGUS1__,			NULL,				NULL)

	//       (id,                       	szLabel,           	szStatusMsg)

	MenuLabel(AP_MENU_ID_FILE,				"&Fjl",			NULL)
	MenuLabel(AP_MENU_ID_FILE_NEW,			"&j", 			"j dokumentum ltrehozsa")	
	MenuLabel(AP_MENU_ID_FILE_OPEN,			"Meg&nyits",			"Dokumentum megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_CLOSE,		"&Bezrs", 			"Dokumentum bezrsa")
	MenuLabel(AP_MENU_ID_FILE_SAVE,			"&Ments", 			"Dokumentum mentse")
	MenuLabel(AP_MENU_ID_FILE_SAVEAS,		"Ments &msknt", 		"Dokumentum mentse ms nven")
	MenuLabel(AP_MENU_ID_FILE_PAGESETUP,	"&Oldalbellts",		"Nyomtatsi belltsok")
	MenuLabel(AP_MENU_ID_FILE_PRINT,		"&Nyomtats",			"A teljes dokumentum, vagy egy rsznek nyomtatsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_1,		"&1 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_2,		"&2 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_3,		"&3 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_4,		"&4 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_5,		"&5 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_6,		"&6 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_7,		"&7 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_8,		"&8 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_RECENT_9,		"&9 %s",			"Ennek a dokumentumnak a megnyitsa")
	MenuLabel(AP_MENU_ID_FILE_EXIT,			"&Kilps", 			"Az alkalmazs sszes ablaknak bezrsa s kilps")

	MenuLabel(AP_MENU_ID_EDIT,				"&Szerkeszts",			NULL)
	MenuLabel(AP_MENU_ID_EDIT_UNDO,			"&Visszavon",			"Szerkeszts visszavonsa")
	MenuLabel(AP_MENU_ID_EDIT_REDO,			"j&ra",			"Az elz visszavons jra")
	MenuLabel(AP_MENU_ID_EDIT_CUT,			"&Kivgs",				"A kijellt rszt kivgja, s a vglapra helyezi")
	MenuLabel(AP_MENU_ID_EDIT_COPY,			"&Msols",			"A kijellt rszt a vglapra msolja")
	MenuLabel(AP_MENU_ID_EDIT_PASTE,		"&Beilleszts",			"A vglap tartalmt beszrja")
	MenuLabel(AP_MENU_ID_EDIT_CLEAR,		"&Trls",			"A kijells trlse")
	MenuLabel(AP_MENU_ID_EDIT_SELECTALL,	"Mindent kijel&l",		"A teljes dokumentum kijellse")
	MenuLabel(AP_MENU_ID_EDIT_FIND,			"Kere&s",			"A megadott szveg keresse")
	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"Cs&erl",			"A megadott szveg cserje ms szvegre")
	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"U&grs",			"A kurzor thelyezse egy megadott helyre")
	
	MenuLabel(AP_MENU_ID_VIEW,				"&Nzet",			NULL)
	MenuLabel(AP_MENU_ID_VIEW_TOOLBARS,		"&Eszkztrak",		NULL)
	MenuLabel(AP_MENU_ID_VIEW_TB_STD,		"&Szabvny",		"A szabvny eszkztr megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_TB_FORMAT,	"&Formzs",		"A formzs eszkztr megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_TB_EXTRA,		"E&xtra",			"Az extra eszkztr megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_RULER,		"&Vonalz",			"A vonalzk megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_STATUSBAR,	"llapot&sor",		"Az llapotsor megjelentse vagy elrejtse")
	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Bekezdsjelek",	"A nem nyomtatott karakterek megjelentse")
	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Fejlc s lblc",	"Az oldalak tetejn s aljn lv szveg szerkesztse")
	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Nagyts",			"A dokumentum nzet nagytsa vagy kicsinytse")

	MenuLabel(AP_MENU_ID_INSERT,			"&Beszrs",			NULL)
	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"Trspont",			"Oldal-, Hasb-, vagy Szekcitrs beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_PAGENO,		"&Oldalszm",	"Automatikusan frisstett oldalszm beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"&Dtum s id",	"Dtum s/vagy id beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Mez",			"Szmtott mez beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Szimblum",			"Szimblum vagy specilis karakter beszrsa")
	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"K&p",			"Meglv kp beszrsa fjlbl")

	MenuLabel(AP_MENU_ID_FORMAT,			"F&ormtum",			NULL)
	MenuLabel(AP_MENU_ID_FMT_FONT,			"&Bet",			"A kijellt szvegrsz bettpusnak megvltoztatsa")
	MenuLabel(AP_MENU_ID_FMT_PARAGRAPH,		"Be&kezds",		"A kijellt bekezds formzsa")
	MenuLabel(AP_MENU_ID_FMT_BULLETS,		"Fel&sorols",	"Felsorols hozzrendelse vagy mdostsa kijellt bekezdsekhez")
	MenuLabel(AP_MENU_ID_FMT_BORDERS,		"Sze&gly s rnyk",		"Szegly s rnyk hozzrendelse a kijellt rszhez")
	MenuLabel(AP_MENU_ID_FMT_COLUMNS,		"&Hasbok",			"A hasbok szmnak megvltoztatsa")
	MenuLabel(AP_MENU_ID_FMT_STYLE,			"S&tlus",			"Stlus megadsa vagy alkalmazsa a kijellt rszhez")
	MenuLabel(AP_MENU_ID_FMT_TABS,			"&Tabultorok",			"Tabultorok belltsa")
	MenuLabel(AP_MENU_ID_FMT_BOLD,			"&Flkvr",			"A kijellt rsz flkvrr ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_ITALIC,		"&Dlt",			"A kijellt rsz dltt ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_UNDERLINE,		"&Alhzs",		"A kijellt rsz alhzsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_OVERLINE,		"Fellvons",		"A kijellt rsz fellvonsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_STRIKE,		"Kihzs",			"A kijellt rsz kihzsa (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_SUPERSCRIPT,	"Fels index",		"A kijellt rsz fels indexsz ttele (megfordts)")
	MenuLabel(AP_MENU_ID_FMT_SUBSCRIPT,		"Als index",		"A kijellt rsz als indexsz ttele (megfordts)")

	MenuLabel(AP_MENU_ID_TOOLS,		"&Eszkzk",		NULL)
	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Helyesrs",		"A dokumentum helyesrsnak ellenrzse")
	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,		"&Szavak szma",		"A dokumentum szavainak megszmllsa")
	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Belltsok",			"Belltsok szerkesztse")

	MenuLabel(AP_MENU_ID_ALIGN,				"&Igazts",			NULL)
	MenuLabel(AP_MENU_ID_ALIGN_LEFT,		"&Balra",			"A bekezds igaztsa balra")
	MenuLabel(AP_MENU_ID_ALIGN_CENTER,		"&Kzpre",			"A bekezds igaztsa kzpre")
	MenuLabel(AP_MENU_ID_ALIGN_RIGHT,		"&Jobbra",			"A bekezds igaztsa jobbra")
	MenuLabel(AP_MENU_ID_ALIGN_JUSTIFY,		"&Sorkiegyenlts",			"A bekezds sorkiegyenltse")

	MenuLabel(AP_MENU_ID_WINDOW,			"&Ablak",			NULL)
	MenuLabel(AP_MENU_ID_WINDOW_NEW,		"&j ablak",		"j ablak nyitsa a dokumentumnak")
	MenuLabel(AP_MENU_ID_WINDOW_1,			"&1 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_2,			"&2 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_3,			"&3 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_4,			"&4 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_5,			"&5 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_6,			"&6 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_7,			"&7 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_8,			"&8 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_9,			"&9 %s",			"Ezt az ablakot mutassa")
	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Tovbbi ablakok",	"Az ablakok teljes listja")

	MenuLabel(AP_MENU_ID_HELP,				"S&g",			NULL)
	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"Sg &Tartalom",	"Sg tartalmnak megjelentse")
	MenuLabel(AP_MENU_ID_HELP_INDEX,		"Sg Tartalomjegyzk",		"Sg tartalomjegyzknek megjelentse")
	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"&Verziszm",	"A program verziszmnak megjelentse")
	MenuLabel(AP_MENU_ID_HELP_SEARCH,		"Sg &Keresse",	"Sg keresse...")
	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"%s &Nvjegy",		"Program informcik, verziszm s copyright megjelentse")
	MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"A &Szabad Forrskdrl",	"Informci a szabad forrskdrl")

	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_3,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_4,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_5,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_6,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_7,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_8,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_SUGGEST_9,	"%s",				"Cserlje erre a javaslatra")
	MenuLabel(AP_MENU_ID_SPELL_IGNOREALL,	"M&indet Kihagy", 		"Hagyja figyelmen kvl a sz dokumentumbeli sszes elfordulst")
	MenuLabel(AP_MENU_ID_SPELL_ADD,			"&Felvesz", 			"Vegye fel ezt a szt az egyedi sztrba")

	// ... add others here ...

	MenuLabel(AP_MENU_ID__BOGUS2__,			NULL,				NULL)

EndSet()
